@@ -109,9 +109,10 @@ func pickAnEditor() (string, string, error) {
 
 func handleEditingRequest(p *Pager) {
 	if os.Getenv("LESSSECURE") == "1" {
-		nope := "Not launching editor since LESSSECURE=1 is set in the environment"
-		p.mode = PagerModeInfo{pager: p, text: nope}
-		log.Info(nope)
+		p.mode = &PagerModeInfo{
+			Pager: p,
+			Text:  "Not launching editor since LESSSECURE=1 is set in the environment",
+		}
 		return
 	}
 
