@@ -3,13 +3,13 @@ package internal
 import (
 	"fmt"
 	"math"
-	"regexp"
 	"sync"
 	"time"
 
 	log "github.com/sirupsen/logrus"
 	"github.com/walles/moor/v2/internal/linemetadata"
 	"github.com/walles/moor/v2/internal/reader"
+	"github.com/walles/moor/v2/internal/search"
 )
 
 // Filters lines based on the search query from the pager.
@@ -17,16 +17,16 @@ import (
 type FilteringReader struct {
 	BackingReader reader.Reader
 
-	// This is a reference to a reference so that we can track changes to the
-	// original pattern, including if it is set to nil.
-	FilterPattern **regexp.Regexp
+	// This is a reference so that we can track changes to the original pattern,
+	// including if it is set to nil.
+	Filter *search.Search
 
 	// Protects filteredLinesCache, unfilteredLineCountWhenCaching, and
 	// filterPatternWhenCaching.
 	lock sync.Mutex
 
 	// nil means no filtering has happened yet
-	filteredLinesCache *[]*reader.NumberedLine
+	filteredLinesCache *[]reader.NumberedLine
 
 	// This is what the reader's line count was when we filtered. If the
 	// reader's current line count doesn't match, then our cache needs to be
@@ -35,30 +35,30 @@ type FilteringReader struct {
 
 	// This is the pattern that was used when we cached the lines. If it
 	// doesn't match the current pattern, then our cache needs to be rebuilt.
-	filterPatternWhenCaching *regexp.Regexp
+	filterWhenCaching search.Search
 }
 
 // Please hold the lock when calling this method.
 func (f *FilteringReader) rebuildCache() {
 	t0 := time.Now()
 
-	cache := make([]*reader.NumberedLine, 0)
-	filterPattern := *f.FilterPattern
+	cache := make([]reader.NumberedLine, 0)
+	filter := *f.Filter
 
 	// Mark cache base conditions
 	f.unfilteredLineCountWhenCaching = f.BackingReader.GetLineCount()
-	f.filterPatternWhenCaching = filterPattern
+	f.filterWhenCaching = filter
 
 	// Repopulate the cache
 	allBaseLines := f.BackingReader.GetLines(linemetadata.Index{}, math.MaxInt)
 	resultIndex := 0
 	for _, line := range allBaseLines.Lines {
-		if filterPattern != nil && len(filterPattern.String()) > 0 && !filterPattern.MatchString(line.Line.Plain(&line.Index)) {
+		if filter.Active() && !filter.Matches(line.Line.Plain(line.Index)) {
 			// We have a pattern but it doesn't match
 			continue
 		}
 
-		cache = append(cache, &reader.NumberedLine{
+		cache = append(cache, reader.NumberedLine{
 			Line:   line.Line,
 			Index:  linemetadata.IndexFromZeroBased(resultIndex),
 			Number: line.Number,
@@ -72,7 +72,7 @@ func (f *FilteringReader) rebuildCache() {
 		len(allBaseLines.Lines)-len(cache), len(allBaseLines.Lines), time.Since(t0))
 }
 
-func (f *FilteringReader) getAllLines() []*reader.NumberedLine {
+func (f *FilteringReader) getAllLines() []reader.NumberedLine {
 	f.lock.Lock()
 	defer f.lock.Unlock()
 
@@ -86,15 +86,15 @@ func (f *FilteringReader) getAllLines() []*reader.NumberedLine {
 		return *f.filteredLinesCache
 	}
 
-	var currentFilterPattern string
-	if *f.FilterPattern != nil {
-		currentFilterPattern = (*f.FilterPattern).String()
+	var currentFilterPattern search.Search
+	if (*f).Filter.Active() {
+		currentFilterPattern = *f.Filter
 	}
-	var cacheFilterPattern string
-	if f.filterPatternWhenCaching != nil {
-		cacheFilterPattern = f.filterPatternWhenCaching.String()
+	var cacheFilterPattern search.Search
+	if f.filterWhenCaching.Active() {
+		cacheFilterPattern = f.filterWhenCaching
 	}
-	if currentFilterPattern != cacheFilterPattern {
+	if !currentFilterPattern.Equals(cacheFilterPattern) {
 		f.rebuildCache()
 		return *f.filteredLinesCache
 	}
@@ -106,7 +106,7 @@ func (f *FilteringReader) shouldPassThrough() bool {
 	f.lock.Lock()
 	defer f.lock.Unlock()
 
-	if *f.FilterPattern == nil || len((*f.FilterPattern).String()) == 0 {
+	if f.Filter == nil || f.Filter.Inactive() {
 		// Cache is not needed
 		f.filteredLinesCache = nil
 
@@ -138,7 +138,7 @@ func (f *FilteringReader) GetLine(index linemetadata.Index) *reader.NumberedLine
 	if index.Index() < 0 || index.Index() >= len(allLines) {
 		return nil
 	}
-	return allLines[index.Index()]
+	return &allLines[index.Index()]
 }
 
 func (f *FilteringReader) GetLines(firstLine linemetadata.Index, wantedLineCount int) reader.InputLines {
@@ -174,6 +174,16 @@ func (f *FilteringReader) GetLines(firstLine linemetadata.Index, wantedLineCount
 	}
 }
 
+func (f *FilteringReader) GetLinesPreallocated(firstLine linemetadata.Index, resultLines *[]reader.NumberedLine) (string, string) {
+	if f.shouldPassThrough() {
+		return f.BackingReader.GetLinesPreallocated(firstLine, resultLines)
+	}
+
+	lines := f.GetLines(firstLine, cap(*resultLines))
+	*resultLines = lines.Lines
+	return lines.FilenameText, lines.StatusText
+}
+
 // In the general case, this will return a text like this:
 // "Filtered: 1234/5678 lines  22%"
 func (f *FilteringReader) createStatus(lastLine *linemetadata.Index) string {
@@ -221,5 +231,5 @@ func (f *FilteringReader) SetBackingReader(r reader.Reader) {
 	// Invalidate caches so they will be rebuilt lazily on next access.
 	f.filteredLinesCache = nil
 	f.unfilteredLineCountWhenCaching = -1
-	f.filterPatternWhenCaching = nil
+	f.filterWhenCaching = search.Search{}
 }
